@@ -1,5 +1,7 @@
 #!/usr/bin/env perl
 package NetHack::Item::Food;
+our $VERSION = '0.04';
+
 use Moose;
 extends 'NetHack::Item';
 
@@ -33,6 +35,8 @@ after incorporate_stats_from => sub {
     $self->incorporate_stat($other => 'is_partly_eaten');
 };
 
+__PACKAGE__->meta->install_spoilers(qw/nutrition time/);
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
