@@ -1,14 +1,16 @@
 #!/usr/bin/env perl
 package NetHack::Item::Other;
+our $VERSION = '0.04';
+
 use Moose;
 extends 'NetHack::Item';
 
 use constant type => "other";
 
 has is_chained_to_you => (
-    is      => 'rw',
-    isa     => 'Bool',
-    default => 0,
+    traits => [qw/IncorporatesUndef/],
+    is     => 'rw',
+    isa    => 'Bool',
 );
 
 has statue => (
@@ -24,6 +26,13 @@ after incorporate_stats => sub {
     $self->statue($stats->{statue}) if exists $stats->{statue};
 };
 
+after incorporate_stats_from => sub {
+    my $self  = shift;
+    my $other = shift;
+
+    $self->incorporate_stat($other => 'is_chained_to_you');
+};
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
