@@ -1,5 +1,7 @@
 #!/usr/bin/env perl
 package NetHack::Item::Role::Damageable;
+our $VERSION = '0.04';
+
 use Moose::Role;
 use MooseX::AttributeHelpers;
 
@@ -11,6 +13,7 @@ has [qw/burnt corroded rotted rusty/]=> (
 
 has proofed => (
     metaclass => 'Bool',
+    traits    => [qw/IncorporatesUndef/],
     is        => 'rw',
     isa       => 'Bool',
     provides  => {
@@ -31,6 +34,14 @@ after incorporate_stats => sub {
         if defined $stats->{proofed};
 };
 
+after incorporate_stats_from => sub {
+    my $self  = shift;
+    my $other = shift;
+
+    $self->incorporate_stat($other => $_)
+        for qw/burnt corroded rotted rusty proofed/;
+};
+
 no Moose::Role;
 
 1;
