@@ -1,10 +1,13 @@
 #!/usr/bin/env perl
 package NetHack::Item::Role::Enchantable;
+our $VERSION = '0.04';
+
 use Moose::Role;
 
 has enchantment => (
-    is  => 'rw',
-    isa => 'Str',
+    is        => 'rw',
+    isa       => 'Str',
+    predicate => 'enchantment_known',
 );
 
 after incorporate_stats => sub {
@@ -22,6 +25,15 @@ after incorporate_stats_from => sub {
     $self->incorporate_stat($other => 'enchantment');
 };
 
+sub numeric_enchantment {
+    my $self = shift;
+    my $enchantment = $self->enchantment;
+
+    return $enchantment unless defined $enchantment;
+    return $1 if $enchantment =~ m{^\+(\d+)$};
+    return $enchantment;
+}
+
 no Moose::Role;
 
 1;
