@@ -1,5 +1,7 @@
 #!/usr/bin/env perl
 package NetHack::Item::Spellbook;
+our $VERSION = '0.04';
+
 use Moose;
 extends 'NetHack::Item';
 
@@ -8,15 +10,14 @@ use constant type => "spellbook";
 sub spell {
     my $self = shift;
 
-    return;
-
-    # XXX: this needs possibility tracking
-
     return unless $self->has_identity;
     return unless $self->identity =~ m{^spellbook of (.*)$};
+    return if $1 eq "blank paper";
     return $1;
 }
 
+__PACKAGE__->meta->install_spoilers(qw/ink level time emergency role/);
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
