@@ -1,5 +1,7 @@
 #!/usr/bin/env perl
 package NetHack::Item::Spoiler::Food;
+our $VERSION = '0.04';
+
 use strict;
 use warnings;
 use base 'NetHack::Item::Spoiler';
@@ -2061,9 +2063,10 @@ sub _list {
     # Collect monster corpses, tins, and eggs
     for my $name (keys %monsterlist) {
         my $stats = $monsterlist{$name};
-        $food->{"$name corpse"}         = $stats;
-        $food->{"$name corpse"}{corpse} = 1;
-        $food->{"$name corpse"}{plural} = "$name corpses";
+        $food->{"$name corpse"}          = $stats;
+        $food->{"$name corpse"}{corpse}  = 1;
+        $food->{"$name corpse"}{subtype} = 'corpse';
+        $food->{"$name corpse"}{plural}  = "$name corpses";
 
         my $tin_name = $name;
         $tin_name .= " meat"
