@@ -1,5 +1,8 @@
+
 #!/usr/bin/env perl
 package NetHack::Item::Spoiler::Ring;
+our $VERSION = '0.04';
+
 use strict;
 use warnings;
 use base 'NetHack::Item::Spoiler';
@@ -19,29 +22,36 @@ sub _list {
             chargeable => 1,
         },
         'ring of hunger' => {
-            price => 100,
+            price      => 100,
+            chargeable => 0,
         },
         'ring of protection' => {
             price      => 100,
             chargeable => 1,
         },
         'ring of protection from shape changers' => {
-            price => 100,
+            price      => 100,
+            chargeable => 0,
         },
         'ring of stealth' => {
-            price => 100,
+            price      => 100,
+            chargeable => 0,
         },
         'ring of sustain ability' => {
-            price => 100,
+            price      => 100,
+            chargeable => 0,
         },
         'ring of warning' => {
-            price => 100,
+            price      => 100,
+            chargeable => 0,
         },
         'ring of aggravate monster' => {
-            price => 150,
+            price      => 150,
+            chargeable => 0,
         },
         'ring of cold resistance' => {
-            price => 150,
+            price      => 150,
+            chargeable => 0,
         },
         'ring of gain constitution' => {
             price      => 150,
@@ -60,49 +70,64 @@ sub _list {
             chargeable => 1,
         },
         'ring of invisibility' => {
-            price => 150,
+            price      => 150,
+            chargeable => 0,
         },
         'ring of poison resistance' => {
-            price => 150,
+            price      => 150,
+            chargeable => 0,
         },
         'ring of see invisible' => {
-            price => 150,
+            price      => 150,
+            chargeable => 0,
         },
         'ring of shock resistance' => {
-            price => 150,
+            price      => 150,
+            chargeable => 0,
         },
         'ring of fire resistance' => {
-            price => 200,
+            price      => 200,
+            chargeable => 0,
         },
         'ring of free action' => {
-            price => 200,
+            price      => 200,
+            chargeable => 0,
         },
         'ring of levitation' => {
-            price => 200,
+            price      => 200,
+            chargeable => 0,
         },
         'ring of regeneration' => {
-            price => 200,
+            price      => 200,
+            chargeable => 0,
         },
         'ring of searching' => {
-            price => 200,
+            price      => 200,
+            chargeable => 0,
         },
         'ring of slow digestion' => {
-            price => 200,
+            price      => 200,
+            chargeable => 0,
         },
         'ring of teleportation' => {
-            price => 200,
+            price      => 200,
+            chargeable => 0,
         },
         'ring of conflict' => {
-            price => 300,
+            price      => 300,
+            chargeable => 0,
         },
         'ring of polymorph' => {
-            price => 300,
+            price      => 300,
+            chargeable => 0,
         },
         'ring of polymorph control' => {
-            price => 300,
+            price      => 300,
+            chargeable => 0,
         },
         'ring of teleport control' => {
-            price => 300,
+            price      => 300,
+            chargeable => 0,
         },
     };
 
