@@ -1,12 +1,16 @@
 #!/usr/bin/env perl
 package NetHack::Item::Tool;
+our $VERSION = '0.04';
+
 use Moose;
 extends 'NetHack::Item';
-with 'NetHack::Item::Role::Chargeable';  # bags of tricks
+with 'NetHack::Item::Role::ChargeBUC';   # bags of tricks
 with 'NetHack::Item::Role::Damageable';  # pick-axe
 
 use constant type => "tool";
 
+__PACKAGE__->meta->install_spoilers('charge');
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
