@@ -1,5 +1,7 @@
 #!/usr/bin/env perl
 package NetHack::Item::Tool::Candelabrum;
+our $VERSION = '0.04';
+
 use Moose;
 extends 'NetHack::Item::Tool::Light';
 
@@ -18,6 +20,13 @@ after incorporate_stats => sub {
     $self->candles_attached($stats->{candles});
 };
 
+after incorporate_stats_from => sub {
+    my $self  = shift;
+    my $other = shift;
+
+    $self->incorporate_stat($other => 'candles_attached');
+};
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
